<?php

// don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/*
Element Description: VC Creatopus LayerSlider
*/
 
class SCP_WPBakeryShortCode_LayerSlider_Vc extends WPBakeryShortCode {

    protected $loaded_slides_collection = array();
     
    function __construct() {
        add_action( 'init', array( $this, 'vc_layerslider_mapping' ) );
        add_shortcode( 'vc_layerslider', array( $this, 'vc_layerslider_html' ) );
    }
     
    public function vc_layerslider_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }

        // Stop all if LayerSlider is not enabled
        if ( ! class_exists( 'LS_Sliders' ) || ! defined( 'LS_ROOT_PATH' ) ) {
            return;
        }

        /*
        Example output for LsSliders::find():
        
            array (size=1)
            0 => 
            array (size=12)
                'id' => string '1' (length=1)
                'author' => string '1' (length=1)
                'name' => string 'Home slide' (length=10)
                'slug' => string 'homeslide123' (length=12)
                'data' => 
                array (size=2)
                    'properties' => 
                    array (size=126)
                        ...
                    'layers' => 
                    array (size=3)
                        ...
                'date_c' => string '1516720343' (length=10)
                'date_m' => string '1518015764' (length=10)
                'schedule_start' => string '0' (length=1)
                'schedule_end' => string '0' (length=1)
                'flag_hidden' => string '0' (length=1)
                'flag_deleted' => string '0' (length=1)
                'flag_popup' => string '0' (length=1)
        */

        $this->loaded_slides_collection = LS_Sliders::find( array(
            'limit' => 999,
            'order' => 'ASC',
        ) );
        $layer_sliders = array();
        if ( ! empty( $this->loaded_slides_collection ) ) {
            foreach ( $this->loaded_slides_collection as $slider ) {
                $target = ! empty( $slider[ 'slug' ] )
                    ? $slider[ 'slug' ]
                    : $slider[ 'name' ];
                $layer_sliders[ $slider[ 'name' ] ] = $target;
            }
        } else {
            $layer_sliders[ __( 'No sliders found', 'airpro' ) ] = 0;
        }
         
        vc_map( 
            array(
                'name' => __('Theme LayerSlider', 'airpro'),
                'base' => 'vc_layerslider',
                'description' => __('Embeds a single slider.', 'airpro'),
                'category' => __('Creatopus', 'airpro'),
                'icon' => plugins_url( 'assets/creatopus-vc-icon.png', __FILE__ ),
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'heading' => __( 'Widget title', 'airpro' ),
                        'param_name' => 'title',
                        'description' => __( 'Enter text used as widget title (Note: located above content element).', 'airpro' )
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => __( 'Target LayerSlider', 'airpro' ),
                        'param_name' => 'target',
                        'admin_label' => true,
                        'value' => $layer_sliders,
                        'save_always' => true,
                        'description' => __( 'Select your slider.', 'airpro' )
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => __( 'Extra class name', 'airpro' ),
                        'param_name' => 'el_class',
                        'description' => __( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'airpro' )
                    ),
                    // CSS
                    array(
                        'type'       => 'css_editor',
                        'heading'    => __( 'CSS box', 'js_composer' ),
                        'param_name' => 'css',
                        'group'      => __( 'Design Options', 'js_composer' )
                    )
                )
            )
        );
    }
     
     
    public function vc_layerslider_html( $atts ) {
        // D:\UwAmp\www\revenuex-test\wp-content\plugins\js_composer\include\templates\shortcodes\layerslider_vc.php

        $output = '';
        extract(
            shortcode_atts(
                array(
                    'title'   => '',
                    'target' => '',
                    'el_class' => '',
                    'css' => ''
                ), 
                $atts
            )
        );

        $el_class = $this->getExtraClass( $el_class );
        $custom_css_class = vc_shortcode_custom_css_class( $css, ' ' );
        $css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, 'wpb_layerslider_element wpb_content_element' . $custom_css_class . ' ' . $el_class, 'vc_layerslider', $atts );

        $id = '';
        foreach ( $this->loaded_slides_collection as $slider ) {
            $slug_matched = ! empty( $slider[ 'slug' ] ) && $slider[ 'slug' ] == $target;
            $id_matched = $slider[ 'id' ] == $target;
            if ( $slug_matched ) {
                $id = $slider[ 'id' ];
            }
            elseif ( $id_matched ) {
                $id = $slider[ 'id' ];
            }
        }

        $output .= '<div class="' . esc_attr( $css_class ) . '">';
        $output .= wpb_widget_title(
            array(
                'title' => $title,
                'extraclass' => 'wpb_layerslider_heading'
            )
        );
        $output .= apply_filters( 'vc_layerslider_shortcode', do_shortcode( '[layerslider id="' . $id . '"]' ) );
        $output .= '</div>';
            
        return $output;
    }     
}
 

new SCP_WPBakeryShortCode_LayerSlider_Vc();   