<?php
/**
 * Theme activation
 */
if ( is_admin() && isset( $_GET['activated'] ) && 'themes.php' == $GLOBALS['pagenow'] ) {
	wp_redirect( admin_url( 'themes.php?page=theme_activation_options' ) );
	exit;
}
add_action( 'admin_menu', 'airpro_theme_activation_options_add_page', 50 );

function airpro_theme_activation_options_add_page() {
	add_theme_page( esc_html__( 'Theme Activation', 'airpro' ), esc_html__( 'Theme Activation', 'airpro' ), 'edit_theme_options', 'theme_activation_options', 'airpro_theme_activation_options_render_page' );
}

function airpro_theme_activation_options_render_page() {
	$theme = wp_get_theme();
	if($theme->parent_theme) {
		$template_dir =  basename(get_template_directory());
		$theme = wp_get_theme($template_dir);
	}
	$theme_version = $theme->get( 'Version' );
	$theme_name = $theme->get( 'Name' );

	?>
	<div class="wrap">
		<h2><?php printf( esc_html__( '%s Theme Activation', 'airpro' ), wp_get_theme() ); ?></h2>

		<p>
			<a style="margin-right: 20px;" target="_blank" href="https://www.youtube.com/watch?v=ZVwBlrMggzo">
				<img class="creatopus-admin-theme-activation-video-thumb" src="<?php echo get_template_directory_uri() . '/assets/img/theme-installation-video-thumb.jpg'?>" alt=""/>
			</a>
			<a target="_blank" href="https://www.youtube.com/watch?v=vSzBNq2hT2Q">
				<img class="creatopus-admin-theme-activation-video-thumb" src="<?php echo get_template_directory_uri() . '/assets/img/theme-update-video-thumb.jpg'?>" alt=""/>
			</a>
		</p>
		<br/>
		<hr/>
		<h3><?php esc_html_e( 'Installation Steps', 'airpro' ); ?></h3>
		<h4><em><?php esc_html_e( 'These settings are optional and should usually be used only on a fresh installation.', 'airpro' ); ?></em></h4>
		<ol>
			<li>
				<p><strong><?php esc_html_e( 'Install required plugins', 'airpro' ); ?></strong></p>
				<p><?php esc_html_e( 'First, enable required plugins. After you finish plugin installation return to this page to complete the installation process.',
						'airpro' ); ?></p>
				<a href="<?php echo admin_url( 'themes.php?page=tgmpa-install-plugins&plugin_status=install' ); ?>"><?php esc_html_e('Install required plugins', 'airpro'); ?></a>
			</li>
			<li>
				<p><strong><?php esc_html_e( 'Import demo content', 'airpro' ); ?></strong></p>
				<p><?php esc_html_e( 'Proceed only after all plugins are installed.', 'airpro' ); ?></p>
				<a href="<?php echo admin_url( 'themes.php?page=pt-one-click-demo-import' ); ?>"><?php esc_html_e('Go to Demo Importer', 'airpro'); ?></a>
			</li>
			<li>
				<p><strong><?php esc_html_e( 'Activate the changed Permalinks settings', 'airpro' ); ?></strong></p>
				<p><?php esc_html_e( 'Visit the Permalinks page and click "Save Changes" once. This will activate the newly configured value.', 'airpro' ); ?></p>
				<a href="<?php echo admin_url( 'options-permalink.php' ); ?>"><?php esc_html_e('Go to Permalinks settings page', 'airpro'); ?></a>
			</li>
		</ol>
		<br>
		<br>
		<hr/>
		<h2>Necessary Preconditions</h2>
		To use AirPro theme, you must be running:
		<ul style="list-style:disc; list-style-position: inside;">
			<li>WordPress 4.6 or higher</li>
			<li>PHP 5.4 or higher</li>
			<li>MySql 5 or higher</li>
		</ul>

		<h2>Recommended (but not Mandatory) Settings for Theme Upload</h2>
		It is recommended to set the following PHP environment setting to the specified value: 
		<ul style="list-style:disc; list-style-position: inside;">
			<li>upload_max_filesize 32M</li>
		</ul>
		Changing this value is not mandatory. Theme can be installed without changing this setting, but in that case theme files should be uploaded to server manually (through an FTP client or CPanel).

		<h2>Recommended (but not Mandatory) Settings for Theme Installation & Demo Content Import</h2>
		We've tried hard to make the theme as flexible as possible, i.e. to support the widest range of hosting providers.
		However, some providers tend to set very strict limits for certain PHP environment variables. If PHP configuration limits are set too low, that might affect the installation/activation process, and cause issues such as: white screen, demo content fails when importing and other similar issues. The solution is to increase the PHP limits. You can do this on your own, or contact your web host and ask them to increase those limits to a minimum as follows:
		<ul style="list-style:disc; list-style-position: inside;">
			<li>max_execution_time 180</li>
			<li>memory_limit 128M</li>
			<li>post_max_size 32M</li>
		</ul>
	</div>
<?php
}
