<?php
/**
 * Custom functions
 */

add_action( 'wp_head', 'airpro_custom_css' );
add_action( 'wp_head', 'airpro_custom_js_code' );
add_action( 'wp_head', 'airpro_responsive_menu_scripts' );
add_action( 'wp_head', 'airpro_add_layout_blocks_css' );

add_filter( 'wp_nav_menu_items', 'airpro_wcmenucart', 10, 2 );

function airpro_add_layout_blocks_css() {

	$top_bar_layout_block = airpro_get_layout_block( 'top-bar-layout-block' );
	$has_custom_top_bar_layout_block = isset( $top_bar_layout_block );
	$top_bar_layout_block_id = $has_custom_top_bar_layout_block
		? $top_bar_layout_block->ID
		: airpro_get_option( 'top-bar-layout-block', false );
	echo airpro_get_vc_page_custom_css( $top_bar_layout_block_id );
	echo airpro_get_vc_shortcodes_custom_css( $top_bar_layout_block_id );

	$footer_layout_block = airpro_get_layout_block( 'footer-layout-block' );
	$has_custom_footer_layout_block = isset( $footer_layout_block );
	$footer_layout_block_id = $has_custom_footer_layout_block
		? $footer_layout_block->ID
		: airpro_get_option( 'footer-layout-block', false );
	echo airpro_get_vc_page_custom_css( $footer_layout_block_id );
	echo airpro_get_vc_shortcodes_custom_css( $footer_layout_block_id );
}

function airpro_get_vc_page_custom_css( $id ) {

	$out = '';
	if ( $id ) {
		$post_custom_css = get_post_meta( $id, '_wpb_post_custom_css', true );
		if ( ! empty( $post_custom_css ) ) {
			$out .= '<style type="text/css" data-type="vc_custom-css">';
			$out .= $post_custom_css;
			$out .= '</style>';
		}
	}
	return $out;
}

function airpro_get_vc_shortcodes_custom_css( $id ) {

	$out = '';
	if ( $id ) {
		$shortcodes_custom_css = get_post_meta( $id, '_wpb_shortcodes_custom_css', true );
		if ( ! empty( $shortcodes_custom_css ) ) {
			$out .= '<style type="text/css" data-type="vc_shortcodes-custom-css">';
			$out .= $shortcodes_custom_css;
			$out .= '</style>';
		}
	}
	return $out;
}

/**
 * Place a cart icon with number of items and total cost in the menu bar.
 *
 * Source: http://wordpress.org/plugins/woocommerce-menu-bar-cart/
 */
function airpro_wcmenucart( $menu, $args ) {

	$cart_is_always_hidden = airpro_get_option( 'woocommerce-hide-always', false );
	if ( $cart_is_always_hidden ) {
		return $menu;
	}

	// Check if WooCommerce is active and add a new item to a menu assigned to Primary Menu menu location
	$woocommerce_is_active = function_exists( 'WC' );
	$current_menu_is_not_primary_menu = 'primary_navigation' !== $args->theme_location;
	if ( ! $woocommerce_is_active || $current_menu_is_not_primary_menu ) {
		return $menu;
	}

	ob_start();
	get_template_part( 'templates/woocommerce-cart' );
	$cart_markup = ob_get_clean();

	ob_start();
	global $woocommerce;
	$shop_id = function_exists( 'wc_get_page_id' ) ? wc_get_page_id( 'shop' ) : woocommerce_get_page_id( 'shop' );
	$cart_contents_count = $woocommerce->cart->cart_contents_count;
	$menu_item     = '';
	// Uncomment the line below to hide nav menu cart item when there are no items in the cart
	//if ( $cart_contents_count > 0 ) {
		$menu_item = '<li class="menu-item crea-cart-menu-item">' . $cart_markup;
		$menu_item .= '</li>';
	//}
	echo '' . $menu_item;
	$shopping = ob_get_clean();

	return $menu . $shopping;
}

function airpro_register_custom_thumbnail_sizes() {
	$string = airpro_get_option( 'custom-thumbnail-sizes' );

	if ( $string ) {

		$pattern     = '/[^a-zA-Z0-9\-\|\:]/';
		$replacement = '';
		$string      = preg_replace( $pattern, $replacement, $string );

		$resArr = explode( '|', $string );
		$thumbs = array();

		foreach ( $resArr as $thumbString ) {
			if ( ! empty( $thumbString ) ) {
				$parts               = explode( ':', trim( $thumbString ) );
				$thumbs[ $parts[0] ] = explode( 'x', $parts[1] );
			}
		}

		foreach ( $thumbs as $name => $sizes ) {
			add_image_size( $name, (int) $sizes[0], (int) $sizes[1], true );
		}
	}
}

if ( ! function_exists( 'airpro_entry_meta' ) ) {

	/**
	 * Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
	 *
	 * @return void
	 */
	function airpro_entry_meta() {



		if ( is_sticky() && is_home() && ! is_paged() ) {
			echo '<span class="featured-post">' . esc_html__( 'Sticky', 'airpro' ) . '</span>';
		}

		if ( ! has_post_format( 'link' ) && 'post' == get_post_type() ) {
			airpro_entry_date();
		}

		// Translators: used between list items, there is a space after the comma.
		$categories_list = get_the_category_list( esc_html__( ', ', 'airpro' ) );
		if ( $categories_list ) {
			echo '<span class="categories-links"><i class="icon-bookmark"></i>' . $categories_list . '</span>';
		}

		// Translators: used between list items, there is a space after the comma.
		$tag_list = get_the_tag_list( '', esc_html__( ', ', 'airpro' ) );
		if ( $tag_list ) {
			echo '<span class="tags-links"><i class="icon-price-tag"></i> ' . $tag_list . '</span>';
		}

		// Post author
		if ( 'post' == get_post_type() ) {
			printf( '<span class="author vcard"><i class="icon-user"></i> %1$s <a class="url fn n" href="%2$s" title="%3$s" rel="author">%4$s</a></span>', esc_html__( 'by', 'airpro' ), esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				esc_attr( sprintf( esc_html__( 'View all posts by %s', 'airpro' ), get_the_author() ) ), get_the_author() );
		}


		if ( 'post' == get_post_type() ) {
			$num_comments = get_comments_number(); // get_comments_number returns only a numeric value

			if ( $num_comments == 0 ) {

			} else {

				if ( $num_comments > 1 ) {
					$comments = $num_comments . esc_html__( ' Comments', 'airpro' );
				} else {
					$comments = esc_html__( '1 Comment', 'airpro' );
				}
				echo '<span class="comments-count"><i class="icon-comment"></i><a href="' . get_comments_link() . '">' . $comments . '</a></span>';
			}

		}



	}
}

if ( ! function_exists( 'airpro_entry_date' ) ) {

	/**
	 * Prints HTML with date information for current post.
	 *
	 * @param boolean $echo Whether to echo the date. Default true.
	 *
	 * @return string The HTML-formatted post date.
	 */
	function airpro_entry_date( $echo = true ) {
		if ( has_post_format( array( 'chat', 'status' ) ) ) {
			$format_prefix = _x( '%1$s on %2$s', '1: post format name. 2: date', 'airpro' );
		} else {
			$format_prefix = '%2$s';
		}

		$date = sprintf( '<span class="date"><i class="icon-calendar"></i><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a></span>', esc_url( get_permalink() ),
			esc_attr( sprintf( esc_html__( 'Permalink to %s', 'airpro' ), the_title_attribute( 'echo=0' ) ) ), esc_attr( get_the_date( 'c' ) ), esc_html( sprintf( $format_prefix, get_post_format_string( get_post_format() ), get_the_date() ) ) );

		if ( $echo ) {
			echo $date;
		}

		return $date;
	}

}

function airpro_add_editor_style() {
	add_editor_style ( 'editor-style.css' );
}
