<?php

add_action( 'after_setup_theme', 'airpro_setup' );
add_action( 'widgets_init', 'airpro_widgets_init' );
add_action( 'widgets_init', 'airpro_override_woocommerce_widgets' );
add_action('admin_head', 'airpro_custom_fonts');

function airpro_custom_fonts() {
	echo '<style>
    .redux-notice {
        display: none;
    }
	.creatopus-admin-theme-activation-video-thumb {
		width: 376px; height: 335px;
	}
  </style>';
}

if ( ! function_exists( 'airpro_setup' ) ) {

	function airpro_setup() {

		add_filter('airpro_alt_buttons', 'airpro_add_to_alt_button_list');

		require_once get_template_directory() . '/lib/redux/redux-settings.php';
		require_once get_template_directory() . '/lib/redux/options.php';
		require_once get_template_directory() . '/lib/metaboxes.php';

		// Make theme available for translation
		load_theme_textdomain( 'airpro', get_template_directory() . '/languages' );

		// Register wp_nav_menu() menus (http://codex.wordpress.org/Function_Reference/register_nav_menus)
		register_nav_menus( array(
			'primary_navigation' => esc_html__( 'Primary Menu', 'airpro' ),
		) );
		register_nav_menus( array(
			'secondary_navigation' => esc_html__( 'Secondary Menu', 'airpro' ),
		) );
		register_nav_menus( array(
			'top_navigation' => esc_html__( 'Top Navigation', 'airpro' ),
		) );

		// Add post thumbnails (http://codex.wordpress.org/Post_Thumbnails)
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 150, 150, false );

		add_image_size( 'airpro-featured-image', 895, 430, true );
		add_image_size( 'airpro-home-page-thumbnail', 480, 320, true );

		// Add post formats (http://codex.wordpress.org/Post_Formats)
		add_theme_support( 'post-formats', array(
			'aside',
			'gallery',
			'link',
			'image',
			'quote',
			'status',
			'video',
			'audio',
			'chat'
		) );
		add_theme_support( 'automatic-feed-links' );

		airpro_register_custom_thumbnail_sizes();

		add_theme_support( 'woocommerce' );
		// https: //createandcode.com/broken-photo-gallery-and-lightbox-after-woocommerce-3-0-upgrade/
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );
	}
}

function airpro_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Primary', 'airpro' ),
		'id'            => 'wheels-sidebar-primary',
		'before_widget' => '<div class="widget %1$s %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Child Pages', 'airpro' ),
		'id'            => 'wheels-sidebar-child-pages',
		'before_widget' => '<div class="widget %1$s %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	$woocommerce_is_active = function_exists( 'WC' );

	if ( $woocommerce_is_active ) {
		register_sidebar( array(
			'name'          => esc_html__( 'WooCommerce Sidebar', 'airpro' ),
			'id'            => 'wheels-sidebar-woocommerce',
			'before_widget' => '<div class="widget %1$s %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h5 class="widget-title">',
			'after_title'   => '</h5>',
		) );
	}
}

function airpro_add_to_alt_button_list($alt_button_arr) {

	$alt_button_arr[] = '.yith-wcwl-add-button a';

	return $alt_button_arr;

}

function airpro_override_woocommerce_widgets() {
	if ( ! class_exists( 'WC_Widget_Price_Filter' ) ) {
		return;
	}

	unregister_widget( 'WC_Widget_Price_Filter' );
	include_once( realpath( __DIR__ . '/../woocommerce-widgets/class-wc-widget-price-filter.php' ) );
	register_widget( 'AirPro_WC_Widget_Price_Filter' );
}
